@@ -10,7 +10,7 @@ This module contains a custom exception definition regarding to BioStudies clien
 
 
 class RestErrorException(Exception):
-    """ Custom exception dealing with REST error responses, """
+    """ Custom exception dealing with REST error responses. """
 
     def __init__(self, message, status_code):
         super().__init__(message, status_code)
